
spongeshaker
============

Version 1.1
-----------

* Keccak now uses optimized implementation by default.
* Fix potential crash on 32-bit architectures due to wrong sizeof.
* Generic base classes for PRNG and StreamCipher.

Version 1.0
-----------

* Initial release.

